pylint
Author: Stephan Müller

##### lccalib.averaging

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 466 | 1 | warning |  | T = T[T["ra"] != 0] # todo remove this as soon as mklc is fixed | fixme | W0511
Source | 86 | 0 | refactor | star_lc_averager | Too many positional arguments (6/5) | too-many-positional-arguments | R0917
Source | 272 | 0 | refactor | _deprecated_night_averager | Too many positional arguments (6/5) | too-many-positional-arguments | R0917
Source | 421 | 4 | warning | chain_averaging | Possible unbalanced tuple unpacking with sequence defined at line 407: left side has 3 labels, right side has 4 values | unbalanced-tuple-unpacking | W0632
Source | 411 | 27 | warning | chain_averaging | Unused argument 'logger' | unused-argument | W0613

##### lccalib.match

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 110 | 39 | error | NearestNeighAssoc.append | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 146 | 39 | error | NearestNeighAssoc.match | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 259 | 39 | error | NearestNeighAssocHealpy.append | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 291 | 39 | error | NearestNeighAssocHealpy.match | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606

##### lccalib.zp

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 10 | 0 | error |  | No name 'make_bins' in module 'saltworks.plottools' | no-name-in-module | E0611
Source | 13 | 0 | error |  | Unable to import 'bbf.bspline' | import-error | E0401
Source | 86 | 0 | refactor | plot_diff_mag | Too many positional arguments (7/5) | too-many-positional-arguments | R0917
Source | 142 | 0 | refactor | _zp_fit | Too many positional arguments (6/5) | too-many-positional-arguments | R0917
Source | 219 | 0 | refactor | compute_zp | Too many positional arguments (8/5) | too-many-positional-arguments | R0917
Source | 327 | 8 | warning | zpfit_diagnostic | Unused variable 'bins' | unused-variable | W0612
Source | 334 | 8 | warning | zpfit_diagnostic | Unused variable 'nmeas' | unused-variable | W0612
Source | 12 | 0 | warning |  | Unused make_index imported from saltworks.indextools | unused-import | W0611